@@ -26,7 +26,10 @@ class ID:
 
     @classmethod
     def from_object(cls, obj: Model) -> 'ID':
-        return ID(ID.kind_for_model(obj), obj.pk)
+        pk = obj.pk
+        if isinstance(pk, uuid.UUID):
+            pk = str(pk)
+        return ID(ID.kind_for_model(obj), pk)
 
     @staticmethod
     def kind_for_model(obj: Union[Model, Type[Model]]):
